==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/PodOSBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodOSBuilder extends PodOSFluentImpl<PodOSBuilder> implements VisitableBuilder<PodOS,PodOSBuilder>{
  public PodOSBuilder() {
    this(false);
  }
  public PodOSBuilder(Boolean validationEnabled) {
    this(new PodOS(), validationEnabled);
  }
  public PodOSBuilder(PodOSFluent<?> fluent) {
    this(fluent, false);
  }
  public PodOSBuilder(PodOSFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodOS(), validationEnabled);
  }
  public PodOSBuilder(PodOSFluent<?> fluent,PodOS instance) {
    this(fluent, instance, false);
  }
  public PodOSBuilder(PodOSFluent<?> fluent,PodOS instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodOSBuilder(PodOS instance) {
    this(instance,false);
  }
  public PodOSBuilder(PodOS instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodOSFluent<?> fluent;
  Boolean validationEnabled;
  public PodOS build() {
    PodOS buildable = new PodOS(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/PodOSBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodOSBuilder extends PodOSFluent<PodOSBuilder> implements VisitableBuilder<PodOS,PodOSBuilder>{
  public PodOSBuilder() {
    this(false);
  }
  public PodOSBuilder(Boolean validationEnabled) {
    this(new PodOS(), validationEnabled);
  }
  public PodOSBuilder(PodOSFluent<?> fluent) {
    this(fluent, false);
  }
  public PodOSBuilder(PodOSFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodOS(), validationEnabled);
  }
  public PodOSBuilder(PodOSFluent<?> fluent,PodOS instance) {
    this(fluent, instance, false);
  }
  public PodOSBuilder(PodOSFluent<?> fluent,PodOS instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PodOS());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodOSBuilder(PodOS instance) {
    this(instance,false);
  }
  public PodOSBuilder(PodOS instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PodOS());

    if (instance != null) {
      this.withName(instance.getName());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodOSFluent<?> fluent;
  Boolean validationEnabled;
  public PodOS build() {
    PodOS buildable = new PodOS(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
